@@ -1,17 +1,13 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Dvaered Diplomacy">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <priority>2</priority>
-  <chance>30</chance>
-  <done>Dvaered Escape</done>
-  <location>Bar</location>
-  <faction>Dvaered</faction>
-  <cond>var.peek("dv_pirate_debt") == false</cond>
- </avail>
+ <unique />
+ <priority>2</priority>
+ <chance>30</chance>
+ <done>Dvaered Escape</done>
+ <location>Bar</location>
+ <faction>Dvaered</faction>
+ <cond>var.peek("dv_pirate_debt") == false</cond>
  <notes>
   <campaign>Frontier Invasion</campaign>
   <done_evt name="Repay General Klank"/>
@@ -38,28 +34,27 @@ local fw = require "common.frontier_war"
 require "proximity"
 local fmt = require "format"
 local pir = require "common.pirate"
+local ai_setup = require "ai.core.setup"
 
 local attackhooks, badguys, escort, hamelsen, tamteam, target, targetList, toldya -- Non-persistent state
 local compute_reward, elt_dest_inlist, increment_baddie, payNfinish, spawnBaddies, spawnEscort, spawnHamelsen, start_battle -- Forward-declared functions
--- luacheck: globals badInPosition baddie_attacked baddie_death baddie_jump baddie_land enter escort_died1 escort_died2 escort_died3 escort_hailed land lastOne_died lastOne_jumped lastOne_landed roastedTam strafer_choosePoint straferReturns straferScans tamDied tamNattack (Hook functions passed by name)
--- luacheck: globals discussWithTam (NPC functions passed by name)
 
 escort_hailed = fw.escort_hailed -- common hooks
 
 -- Mission constants
-local destpla, destsys = planet.getS("Mannannan")
+local destpla, destsys = spob.getS("Mannannan")
 local lore_text = {}
 
-lore_text[1] = _([["Good question, citizen! It is likely the intelligence services of the other nations know that General Klank and I are involved in the invasion project. Though, they probably don't know how imminent it is. It's likely they hired henchmen to hound or outright stop us. We have identified some of the henchmen actually. They are the kind of independent mercenaries we find in any kind of shady operations... A bit like you in fact."]])
+lore_text[1] = _([["Good question, citizen! It is likely the intelligence services of the other nations know that General Klank and I are involved in the invasion project. Though, they probably don't know how imminent it is. It's likely they hired henchmen to hound or outright stop us. We have identified some of the henchmen, actually. They are the kind of independent mercenaries we find in any kind of shady operations... A bit like you in fact."]])
 
 lore_text[2] = _([["Aha! You're worrying about the soldiers of the warlord we killed last time? Don't worry too much about them, most of them did not stay unemployed for long. When a warlord dies, his surviving followers are sent to the Dvaered Military Reserve, and they apply for positions in other warlords' armies, or in the DHC. The only one I'm worried about is Colonel Hamelsen: it will be very difficult for her to find a position with a warlord since they prefer to have people they know at higher ranks, and the DHC only rarely recruits new colonels.
    "That's a pity actually because she is probably the most talented officer of her generation. Do you know that she was the first one since the Independence War who managed to become an ace before the end of her training?"]])
 
-lore_text[3] = _([[You ask Major Tam to continue his story about when he used to be a fighter pilot at the DHC base on Rhaana. A small smile appears on his face and he turns his eyes to the cieling.
-   "Do you want me to tell you how I became an ace? Oh yes, you do. So. To become a Dvaered ace, one has to score four confirmed fighter victories. An confirmed victory is recorded when you, alone, destroy any kind of enemy warship. As we tend to work in squads, we pretty often destroy ships without scoring any confirmed victories. My first victory was a Pirate Hyena. The pilot was probably drunk or something. They headed right towards my Vendetta, broadcasting stupid taunts. My sergeant was nice and left the Hyena all to me. My second victory was against a freak... I mean a local warlord's pilot who claimed she could kill any DHC pilot in fair fight. Apparently, it was not true.
-   "But the two others... Actually those are a much longer story. I'll tell you another time maybe."]])
+lore_text[3] = _([[You ask Major Tam to continue his story about when he used to be a fighter pilot at the DHC base on Rhaana. A small smile appears on his face, and he turns his eyes to the ceiling.
+   "Do you want me to tell you how I became an ace? Oh yes, you do. So. To become a Dvaered ace, one has to score four confirmed fighter victories. A confirmed victory is recorded when you, alone, destroy any kind of enemy warship. As we tend to work in squads, we pretty often destroy ships without scoring any confirmed victories. My first victory was a Pirate Hyena. The pilot was probably drunk or something. They headed right towards my Vendetta, broadcasting stupid taunts. My sergeant was nice and left the Hyena all to me. My second victory was against a freak... I mean a local warlord's pilot who claimed she could kill any DHC pilot in fair fight. Apparently, it was not true.
+   "But the two others... Actually those are a much longer story. I'll tell you another time, maybe."]])
 
-lore_text[4] = _([["Oh, the captain is doing well. He spent a few periods at the hospital, but it was not so serious. The rest of his squad, I'm not too sure. I don't know them very well actually. They are more like statistics to me. I know it's bad, but hey, I have so many things to think about right now.
+lore_text[4] = _([["Oh, the captain is doing well. He spent a few periods at the hospital, but it was not so serious. The rest of his squad, I'm not too sure. I don't know them very well, actually. They are more like statistics to me. I know it's bad, but hey, I have so many things to think about right now.
    "Oh, and we went to the funeral of private Amadeus Tronk, officially killed in training, of course. It was nice. Leblanc's squadron made an aerial display with a mace rocket concerto for the occasion, and we organized a fight to death between a convicted criminal and a gladiator in General Klank's private arena. Not only to honour the memory of the dead warrior, but also to have some fun."]])
 
 local flee_text = _("You were supposed to wait for Strafer to scan the system, and then if needed, kill the hostiles.")
@@ -87,10 +82,10 @@ end
 
 function accept()
    if not tk.yesno( _("Ready for some diplomacy?"), fmt.f(_([[Major Tam seems to be in a very good mood: "Hello, citizen {player}! Have you got plans for tonight?" You fear he might invite you to a brawl-party, or some other kind of event Dvaered usually organize when they want to have good time, but he continues: "Because I've got a very important mission for you.
-   "Let me explain: I am currently in the middle of a secret diplomatic campaign with the Imperials, House Goddard, and the Sirii. But a group of assassins is constantly harassing me as I travel. This is very annoying and we have already lost two pilots of Leblanc's squadron in these ambushes, including the second in command. The attackers use a mix of fighters supported by medium ships. They even have a Kestrel!
+   "Let me explain: I am currently in the middle of a secret diplomatic campaign with the Imperials, House Goddard, and the Sirii. But a group of assassins is constantly harassing me as I travel. This is very annoying, and we have already lost two pilots of Leblanc's squadron in these ambushes, including the second in command. The attackers use a mix of fighters supported by medium ships. They even have a Kestrel!
    "So we have decided to deal with them before we proceed with the diplomatic meetings. Are you in?"]]), {player=player.name()}) ) then
       tk.msg(_("Another time maybe"), _([[Major Tam really seems disappointed. "As you wish, citizen..."]]))
-      misn.finish(false)
+      return
    end
    tk.msg(_("This is how we deal with our problems"), fmt.f(_([["You won't regret it!" Tam says... "Unless you're killed in the process I guess... Anyway, I will go to {pnt} in {sys} in my Vigilance. No doubt the assassins will set up an ambush somewhere on the way. You and a few pilots from the Special Operations Force (SOF) will locate them and wait for me to jump in. When they spring the ambush, the assassins will be caught in our crossfire, and we will annihilate them to the last ship. Actually, that sounds much more enticing than a three-period-long meeting with rogue Sirian diplomats, doesn't it?
    "Our side will not have much firepower, so I'm counting on you to arrive with a lot of armour and guns (but you should still be able to outrun mid-range destroyers). Because you two worked so well in the past, you'll again team up with Lieutenant Strafer, and two other pilots. But the SOF does not have an endless supply of pilots, so your reward will depend on how many of them come back. Strafer will fly a scout with high performance sensors. He will be our eyes, so his death would mean the end of the mission.
@@ -99,7 +94,7 @@ function accept()
    misn.accept()
    misn.osdCreate( _("Dvaered Diplomacy"), {_("Go to next system"), _("Wait until Strafer has scanned the system"), _("Wait for Tam and destroy the highlighted hostile ships"), _("Land anywhere to collect your pay") } )
    misn.setDesc(_("You take part in an operation to trap and destroy a group of well armed henchmen who are after Major Tam."))
-   misn.setReward(_("It depends how many of your wingmen come back."))
+   misn.setReward(_("It depends on how many of your wingmen come back."))
 
    -- Markers
    mem.marklist = {}
@@ -110,7 +105,7 @@ function accept()
 
    mem.stage = 0
 
-   mem.previous = planet.cur()
+   mem.previous = spob.cur()
    mem.enterhook = hook.enter("enter")
    mem.landhook = hook.land("land")
 
@@ -149,6 +144,7 @@ function enter()
          -- Decide from where the ambushers come
          if system.cur() == destsys then
             mem.ambStart = destpla
+            ambJp = destpla
          else
             mem.ambStart = lmisn.getNextSystem(system.cur(), destsys)
             ambJp = jump.get(system.cur(), mem.ambStart) -- We assume there are no one-way jumps
@@ -158,10 +154,7 @@ function enter()
          escort[1]:moveto( ambJp:pos() )  -- Let's say Strafer knows where they are supposed to come from...
 
          if system.cur() == mem.ambushsys then
-            for k,f in ipairs(pir.factions) do
-               pilot.toggleSpawn(f)
-               pilot.clearSelect(f)
-            end
+            pir.clearPirates()
             spawnBaddies( mem.ambStart )
 
             -- Find the waiting point: on the line mem.tamPoint -> ambJp, at 3000 of mem.tamPoint
@@ -201,7 +194,7 @@ function enter()
          target:setHealth( mem.arm, mem.sld, mem.str )
          target:setTemp( mem.tem )
          target:setHilight()
-         target:setFaction("Warlords")
+         target:setFaction(fw.fct_warlords())
 
          hook.pilot(target, "death","lastOne_died")
          hook.pilot(target, "jump","lastOne_jumped")
@@ -237,7 +230,7 @@ function land()
 
    -- Landing after an enemy (victory as well)
    elseif mem.stage == 6 then
-      if planet.cur() == mem.nextt then
+      if spob.cur() == mem.nextt then
          compute_reward()
          tk.msg( _("End of the hunt"), fmt.f(_([[You land and walk around the spacedock, in search of your target's ship. You finally see it. A mighty {ship}, covered in the score marks of the battle that just occurred. You hide yourself behind some crates near the ship and wait for the pilot to come back and take off in order to finish your job in space.
    When looking closer at the ship, you see both ancient and recent marks on the hull, caused by all kinds of weapons during the lifetime of the ship. Among the ship's scars, you see a twisted welding around the ship's nose, filled with bubbles and think: "Damn! They had to deal with the same old deficient welding android that fixed my airlock on Alteris last time!"
@@ -256,18 +249,17 @@ function land()
          misn.finish(false)
       end
    end
-   mem.previous = planet.cur()
+   mem.previous = spob.cur()
 end
 
 -- Spawn the escort
 function spawnEscort( origin )
    escort = {}
    if mem.alive[1] then
-      escort[1] = pilot.add( "Schroedinger", "DHC", origin, _("Lieutenant Strafer") )
+      escort[1] = pilot.add( "Schroedinger", fw.fct_dhc(), origin, _("Lieutenant Strafer"), {naked=true} )
 
       -- Give him nice outfits
-      escort[1]:outfitRm("all")
-      escort[1]:outfitRm("cores")
+      -- TODO switch to equipopt
       escort[1]:outfitAdd("Nexus Light Stealth Plating")
       escort[1]:outfitAdd("Tricon Zephyr Engine")
       escort[1]:outfitAdd("Milspec Orion 2301 Core System")
@@ -282,6 +274,7 @@ function spawnEscort( origin )
       escort[1]:setFuel(true)
       escort[1]:setHilight()
       escort[1]:setVisplayer()
+      ai_setup.setup( escort[1] )
 
       escort[1]:memory().angle = math.rad(225)
       escort[1]:memory().radius = 200
@@ -296,7 +289,7 @@ function spawnEscort( origin )
    end
 
    if mem.alive[2] then
-      escort[2] = pilot.add( "Vendetta", "DHC", origin )
+      escort[2] = pilot.add( "Vendetta", fw.fct_dhc(), origin )
       hook.pilot(escort[2], "hail", "escort_hailed")
       hook.pilot(escort[2], "death", "escort_died2")
       escort[2]:control()
@@ -306,7 +299,7 @@ function spawnEscort( origin )
       escort[2]:setVisplayer()
    end
    if mem.alive[3] then
-      escort[3] = pilot.add( "Phalanx", "DHC", origin )
+      escort[3] = pilot.add( "Phalanx", fw.fct_dhc(), origin )
       hook.pilot(escort[3], "hail", "escort_hailed")
       hook.pilot(escort[3], "death", "escort_died3")
       escort[3]:control()
@@ -361,8 +354,9 @@ local function spawnTam( origin )
    tamteam[3] = pilot.add( "Dvaered Vendetta", "Dvaered", origin )
    tamteam[4] = pilot.add( "Dvaered Vendetta", "Dvaered", origin )
 
+   local fdhc = fw.fct_dhc()
    for i,p in ipairs(tamteam) do
-      p:setFaction("DHC")
+      p:setFaction( fdhc )
    end
    hook.pilot(tamteam[1], "death", "tamDied")
 end
@@ -423,7 +417,7 @@ function escort_died3( )
    mem.alive[3] = false
 end
 function tamDied()
-   tk.msg(_("This is not good"), _([[The blinking cross marked "Major Tam" on your radar screen suddenly turns off. At first you think your screen is buggy and hit it with your open hand, but soon, you realize that the radar works perfectly well. This means that the major's ship was annihilated by the ambushers, and therefore your mission is a miserable failure.]]))
+   tk.msg(_("This is not good"), _([[The blinking cross marked "Major Tam" on your radar screen suddenly turns off. At first, you think your screen is buggy and hit it with your open hand, but soon, you realize that the radar works perfectly well. This means that the major's ship was annihilated by the ambushers, and therefore your mission is a miserable failure.]]))
    misn.finish(false)
 end
 
@@ -503,9 +497,10 @@ function baddie_land( pilot, planet )
 end
 
 function start_battle()
+   local fwarlords = fw.fct_warlords()
    badguys[1]:control(false)
    for i,p in ipairs(badguys) do
-      p:setFaction("Warlords")
+      p:setFaction( fwarlords )
    end
    for i,p in ipairs(escort) do
       p:control(false)
@@ -591,7 +586,7 @@ end
 function spawnHamelsen( origin )
    hamelsen = pilot.add( "Schroedinger", "Independent", origin, _("Colonel Hamelsen") )
    hamelsen:setInvincible()
-   hamelsen:setFaction("Warlords")
+   hamelsen:setFaction(fw.fct_warlords())
 
    hamelsen:comm( _("You won't take me alive! Never!") )
    hamelsen:control()
@@ -602,7 +597,7 @@ end
 function payNfinish()
    player.pay(mem.effective_credits)
    shiplog.create( "frontier_war", _("Frontier War"), _("Dvaered") )
-   shiplog.append( "frontier_war", _("A group of assasins, who were after Major Tam, have been trapped and killed. For now, we don't know who paid them, but they were led by Colonel Hamelsen, who managed to escape.") )
+   shiplog.append( "frontier_war", _("A group of assassins, who were after Major Tam, have been trapped and killed. For now, we don't know who paid them, but they were led by Colonel Hamelsen, who managed to escape.") )
    misn.finish(true)
 end
 
